@@ -6,6 +6,8 @@ from tempfile import NamedTemporaryFile
 
 from babelfish import Language
 
+from trakit.api import trakit
+
 from .media import Media, Pgs
 from .media_path import MediaPath
 from .options import Options
@@ -48,7 +50,13 @@ class MkvTrack:
     def language(self):
         lang_ietf = self.properties.get('language_ietf')
         lang_alpha = self.properties.get('language')
-        return Language.fromcleanit(lang_ietf or lang_alpha or 'und')
+        track_name = self.properties.get('track_name')
+
+        language = Language.fromcleanit(lang_ietf or lang_alpha or 'und')
+        options = {'expected_language': language} if language else {}
+        guess = trakit(track_name, options) if track_name else {}
+
+        return guess.get('language') or language
 
     @property
     def forced(self):
