@@ -2,7 +2,8 @@
 import logging
 from typing import Iterable
 
-from .media import Media, Pgs, MediaPath
+from .media import Media, Pgs
+from .media_path import MediaPath
 from .options import Options
 
 logger = logging.getLogger(__name__)
@@ -15,4 +16,6 @@ class Sup(Media):
         super().__init__(media_path, languages={media_path.language})
 
     def get_pgs_medias(self, options: Options) -> Iterable[Pgs]:
-        yield Pgs(self.media_path, data_reader=self.media_path.get_data)
+        pgs = Pgs(self.media_path, data_reader=self.media_path.get_data)
+        if pgs.matches(options):
+            yield pgs
